<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ca_ES">
<context>
    <name>QBluetoothDeviceDiscoveryAgent</name>
    <message>
        <source>Device is powered off</source>
        <translation>El dispositiu està apagat</translation>
    </message>
    <message>
        <source>Cannot find valid Bluetooth adapter.</source>
        <translation>No s&apos;ha pogut trobar un adaptador de Bluetooth vàlid.</translation>
    </message>
    <message>
        <source>Input Output Error</source>
        <translation>Error d&apos;entrada/sortida</translation>
    </message>
    <message>
        <source>Bluetooth LE is not supported</source>
        <translation>El Bluetooth LE no està admès</translation>
    </message>
    <message>
        <source>Unknown error</source>
        <translation>Error desconegut</translation>
    </message>
    <message>
        <source>Missing permission</source>
        <translation>Manca un permís</translation>
    </message>
    <message>
        <source>Cannot start device inquiry</source>
        <translation>No s&apos;ha pogut iniciar la consulta del dispositiu</translation>
    </message>
    <message>
        <source>Cannot start low energy device inquiry</source>
        <translation>No s&apos;ha pogut iniciar la consulta del dispositiu de baixa potència</translation>
    </message>
    <message>
        <source>Discovery cannot be stopped</source>
        <translation>El descobriment de dispositius no es pot aturar</translation>
    </message>
    <message>
        <source>Invalid Bluetooth adapter address</source>
        <translation>L&apos;adreça de l&apos;adaptador de Bluetooth no és vàlida</translation>
    </message>
    <message>
        <source>One or more device discovery methods are not supported on this platform</source>
        <translation>Un o més mètodes de descobriment de dispositius no està admès en aquesta plataforma</translation>
    </message>
    <message>
        <source>Device does not support Bluetooth</source>
        <translation>El dispositiu no admet Bluetooth</translation>
    </message>
    <message>
        <source>Passed address is not a local device.</source>
        <translation>L&apos;adreça indicada no és un dispositiu local.</translation>
    </message>
    <message>
        <source>Missing Location permission. Search is not possible.</source>
        <translation type="vanished">Manca el permís d&apos;ubicació. No es pot cercar.</translation>
    </message>
    <message>
        <source>Location service turned off. Search is not possible.</source>
        <translation>El servei d&apos;ubicació està apagat. No es pot cercar.</translation>
    </message>
    <message>
        <source>Failed to start device discovery due to missing permissions.</source>
        <translation>Ha fallat en iniciar el descobriment de dispositius a causa de la manca de permisos.</translation>
    </message>
    <message>
        <source>Classic Discovery cannot be started</source>
        <translation>No s&apos;ha pogut iniciar el descobriment clàssic</translation>
    </message>
    <message>
        <source>Low Energy Discovery not supported</source>
        <translation type="vanished">No s&apos;admet el descobriment de baixa potència</translation>
    </message>
    <message>
        <source>Discovery cannot be started</source>
        <translation type="vanished">El descobriment de dispositius no s&apos;ha pogut iniciar</translation>
    </message>
    <message>
        <source>Bluetooth adapter error</source>
        <translation>Error a l&apos;adaptador de Bluetooth</translation>
    </message>
    <message>
        <source>Device discovery not supported on this platform</source>
        <translation>El descobriment de dispositius no està admès en aquesta plataforma</translation>
    </message>
    <message>
        <source>Cannot access adapter during service discovery</source>
        <translation>No s&apos;ha pogut accedir a l&apos;adaptador durant el descobriment dels serveis</translation>
    </message>
    <message>
        <source>Bluetooth adapter powered off.</source>
        <translation>L&apos;adaptador de Bluetooth està apagat.</translation>
    </message>
</context>
<context>
    <name>QBluetoothServiceDiscoveryAgent</name>
    <message>
        <source>Local device is powered off</source>
        <translation>El dispositiu local està apagat</translation>
    </message>
    <message>
        <source>Minimal service discovery failed</source>
        <translation>El descobriment de serveis mínim ha fallat</translation>
    </message>
    <message>
        <source>Invalid Bluetooth adapter address</source>
        <translation>L&apos;adreça de l&apos;adaptador de Bluetooth no és vàlida</translation>
    </message>
    <message>
        <source>Platform does not support Bluetooth</source>
        <translation>La plataforma no admet Bluetooth</translation>
    </message>
    <message>
        <source>Android API below v15 does not support SDP discovery</source>
        <translation type="vanished">L&apos;API d&apos;Android per sota de la v15 no admet el descobriment SDP</translation>
    </message>
    <message>
        <source>Failed to start service discovery due to missing permissions.</source>
        <translation>Ha fallat en iniciar el descobriment de dispositius a causa de la manca de permisos.</translation>
    </message>
    <message>
        <source>Cannot create Android BluetoothDevice</source>
        <translation>No s&apos;ha pogut crear el dispositiu de Bluetooth d&apos;Android</translation>
    </message>
    <message>
        <source>Cannot obtain service uuids</source>
        <translation>No s&apos;han pogut obtenir els UUID del servei</translation>
    </message>
    <message>
        <source>Serial Port Profile</source>
        <translation>Perfil del port en sèrie</translation>
    </message>
    <message>
        <source>Device is powered off</source>
        <translation>El dispositiu està apagat</translation>
    </message>
    <message>
        <source>Unable to find appointed local adapter</source>
        <translation type="vanished">No s&apos;ha pogut trobar l&apos;adaptador local apuntat</translation>
    </message>
    <message>
        <source>Cannot find local Bluetooth adapter</source>
        <translation>No s&apos;ha pogut trobar l&apos;adaptador de Bluetooth local</translation>
    </message>
    <message>
        <source>Unable to find sdpscanner</source>
        <translation>No s&apos;ha pogut trobar el «sdpscanner»</translation>
    </message>
    <message>
        <source>Unable to perform SDP scan</source>
        <translation>No s&apos;ha pogut realitzar un escaneig SDP</translation>
    </message>
    <message>
        <source>Unable to access device</source>
        <translation type="vanished">No s&apos;ha pogut accedir al dispositiu</translation>
    </message>
    <message>
        <source>Custom Service</source>
        <translation>Servei personalitzat</translation>
    </message>
    <message>
        <source>Service Discovery</source>
        <translation>Descobriment de serveis</translation>
    </message>
    <message>
        <source>Browse Group Descriptor</source>
        <translation>Descriptor del grup de navegació</translation>
    </message>
    <message>
        <source>Public Browse Group</source>
        <translation>Grup de navegació pública</translation>
    </message>
    <message>
        <source>LAN Access Profile</source>
        <translation>Perfil d&apos;accés a la LAN</translation>
    </message>
    <message>
        <source>Dial-Up Networking</source>
        <translation>Accés telefònic a la xarxa</translation>
    </message>
    <message>
        <source>Synchronization</source>
        <translation>Sincronització</translation>
    </message>
    <message>
        <source>Object Push</source>
        <translation>Puja l&apos;objecte</translation>
    </message>
    <message>
        <source>File Transfer</source>
        <translation>Transferència de fitxers</translation>
    </message>
    <message>
        <source>Synchronization Command</source>
        <translation>Ordre de sincronització</translation>
    </message>
    <message>
        <source>Headset</source>
        <translation>Auriculars</translation>
    </message>
    <message>
        <source>Audio Source</source>
        <translation>Origen de l&apos;àudio</translation>
    </message>
    <message>
        <source>Audio Sink</source>
        <translation>Conducte de l&apos;àudio</translation>
    </message>
    <message>
        <source>Audio/Video Remote Control Target</source>
        <translation>Objectiu del control remot de l&apos;àudio/vídeo</translation>
    </message>
    <message>
        <source>Advanced Audio Distribution</source>
        <translation>Distribució avançada de l&apos;àudio</translation>
    </message>
    <message>
        <source>Audio/Video Remote Control</source>
        <translation>Control remot de l&apos;àudio/vídeo</translation>
    </message>
    <message>
        <source>Audio/Video Remote Control Controller</source>
        <translation>Controlador del control remot de l&apos;àudio/vídeo</translation>
    </message>
    <message>
        <source>Headset AG</source>
        <translation>Auriculars AG</translation>
    </message>
    <message>
        <source>Personal Area Networking (PANU)</source>
        <translation>Xarxa d&apos;àrea personal (PANU)</translation>
    </message>
    <message>
        <source>Personal Area Networking (NAP)</source>
        <translation>Xarxa d&apos;àrea personal (NAP)</translation>
    </message>
    <message>
        <source>Personal Area Networking (GN)</source>
        <translation>Xarxa d&apos;àrea personal (GN)</translation>
    </message>
    <message>
        <source>Basic Direct Printing (BPP)</source>
        <translation>Impressió directa bàsica (BPP)</translation>
    </message>
    <message>
        <source>Basic Reference Printing (BPP)</source>
        <translation>Impressió de referència bàsica (BPP)</translation>
    </message>
    <message>
        <source>Basic Imaging Profile</source>
        <translation>Perfil bàsic d&apos;imatges</translation>
    </message>
    <message>
        <source>Basic Imaging Responder</source>
        <translation>Contestador bàsic d&apos;imatges</translation>
    </message>
    <message>
        <source>Basic Imaging Archive</source>
        <translation>Arxiu bàsic d&apos;imatges</translation>
    </message>
    <message>
        <source>Basic Imaging Ref Objects</source>
        <translation>Objectes de referència bàsica d&apos;imatges</translation>
    </message>
    <message>
        <source>Hands-Free</source>
        <translation>Mans lliures</translation>
    </message>
    <message>
        <source>Hands-Free AG</source>
        <translation>Mans lliures AG</translation>
    </message>
    <message>
        <source>Basic Printing RefObject Service</source>
        <translation>Servei d&apos;objectes de referència d&apos;impressió bàsica</translation>
    </message>
    <message>
        <source>Basic Printing Reflected UI</source>
        <translation>La IU reflectida d&apos;impressió bàsica</translation>
    </message>
    <message>
        <source>Basic Printing</source>
        <translation>Impressió bàsica</translation>
    </message>
    <message>
        <source>Basic Printing Status</source>
        <translation>Estat de la impressió bàsica</translation>
    </message>
    <message>
        <source>Human Interface Device</source>
        <translation>Dispositiu amb interfície humana</translation>
    </message>
    <message>
        <source>Hardcopy Cable Replacement</source>
        <translation>Substitució del cable per una còpia</translation>
    </message>
    <message>
        <source>Hardcopy Cable Replacement Print</source>
        <translation>Impressió amb la substitució del cable per una còpia</translation>
    </message>
    <message>
        <source>Hardcopy Cable Replacement Scan</source>
        <translation>Escaneig amb la substitució del cable per una còpia</translation>
    </message>
    <message>
        <source>SIM Access Server</source>
        <translation>Servidor d&apos;accés SIM</translation>
    </message>
    <message>
        <source>Phonebook Access PCE</source>
        <translation>Accés a la llibreta d&apos;adreces PCE</translation>
    </message>
    <message>
        <source>Phonebook Access PSE</source>
        <translation>Accés a la llibreta d&apos;adreces PSE</translation>
    </message>
    <message>
        <source>Phonebook Access</source>
        <translation>Accés a la llibreta d&apos;adreces</translation>
    </message>
    <message>
        <source>Headset HS</source>
        <translation>Auriculars HS</translation>
    </message>
    <message>
        <source>Message Access Server</source>
        <translation>Servidor d&apos;accés als missatges</translation>
    </message>
    <message>
        <source>Message Notification Server</source>
        <translation>Servidor de notificació dels missatges</translation>
    </message>
    <message>
        <source>Message Access</source>
        <translation>Accés als missatges</translation>
    </message>
    <message>
        <source>Global Navigation Satellite System</source>
        <translation>Sistema de navegació global per satèl·lit</translation>
    </message>
    <message>
        <source>Global Navigation Satellite System Server</source>
        <translation>Servidor del sistema de navegació global per satèl·lit</translation>
    </message>
    <message>
        <source>3D Synchronization Display</source>
        <translation>Pantalla amb sincronització en 3D</translation>
    </message>
    <message>
        <source>3D Synchronization Glasses</source>
        <translation>Ulleres amb sincronització en 3D</translation>
    </message>
    <message>
        <source>3D Synchronization</source>
        <translation>Sincronització en 3D</translation>
    </message>
    <message>
        <source>Multi-Profile Specification (Profile)</source>
        <translation>Especificació amb múltiples perfils (perfil)</translation>
    </message>
    <message>
        <source>Multi-Profile Specification</source>
        <translation>Especificació amb múltiples perfils</translation>
    </message>
    <message>
        <source>Device Identification</source>
        <translation>Identificació del dispositiu</translation>
    </message>
    <message>
        <source>Generic Networking</source>
        <translation>Xarxes genèriques</translation>
    </message>
    <message>
        <source>Generic File Transfer</source>
        <translation>Transferència de fitxers genèrica</translation>
    </message>
    <message>
        <source>Generic Audio</source>
        <translation>Àudio genèric</translation>
    </message>
    <message>
        <source>Generic Telephony</source>
        <translation>Telefonia genèrica</translation>
    </message>
    <message>
        <source>Video Source</source>
        <translation>Origen del vídeo</translation>
    </message>
    <message>
        <source>Video Sink</source>
        <translation>Conducte del vídeo</translation>
    </message>
    <message>
        <source>Video Distribution</source>
        <translation>Distribució del vídeo</translation>
    </message>
    <message>
        <source>Health Device</source>
        <translation>Dispositiu de salut</translation>
    </message>
    <message>
        <source>Health Device Source</source>
        <translation>Origen del dispositiu de salut</translation>
    </message>
    <message>
        <source>Health Device Sink</source>
        <translation>Conducte del dispositiu de salut</translation>
    </message>
    <message>
        <source>Generic Access</source>
        <translation>Accés genèric</translation>
    </message>
    <message>
        <source>Generic Attribute</source>
        <translation>Atribut genèric</translation>
    </message>
    <message>
        <source>Immediate Alert</source>
        <translation>Alerta immediata</translation>
    </message>
    <message>
        <source>Link Loss</source>
        <translation>Pèrdua de l&apos;enllaç</translation>
    </message>
    <message>
        <source>Tx Power</source>
        <translation>Potència de Tx</translation>
    </message>
    <message>
        <source>Current Time Service</source>
        <translation>Servei de l&apos;hora actual</translation>
    </message>
    <message>
        <source>Reference Time Update Service</source>
        <translation>Servei d&apos;actualització de l&apos;hora de referència</translation>
    </message>
    <message>
        <source>Next DST Change Service</source>
        <translation>Servei de canvi següent d&apos;horari d&apos;estiu</translation>
    </message>
    <message>
        <source>Glucose</source>
        <translation>Glucosa</translation>
    </message>
    <message>
        <source>Health Thermometer</source>
        <translation>Termòmetre de salut</translation>
    </message>
    <message>
        <source>Device Information</source>
        <translation>Informació del dispositiu</translation>
    </message>
    <message>
        <source>Heart Rate</source>
        <translation>Ritme cardíac</translation>
    </message>
    <message>
        <source>Phone Alert Status Service</source>
        <translation>Servei de l&apos;estat d&apos;alerta del telèfon</translation>
    </message>
    <message>
        <source>Battery Service</source>
        <translation>Servei de bateria</translation>
    </message>
    <message>
        <source>Blood Pressure</source>
        <translation>Pressió sanguínia</translation>
    </message>
    <message>
        <source>Alert Notification Service</source>
        <translation>Servei de notificació d&apos;alertes</translation>
    </message>
    <message>
        <source>Scan Parameters</source>
        <translation>Paràmetres d&apos;escaneig</translation>
    </message>
    <message>
        <source>Running Speed and Cadence</source>
        <translation>Velocitat i cadència de la carrera</translation>
    </message>
    <message>
        <source>Cycling Speed and Cadence</source>
        <translation>Velocitat i cadència fent ciclisme</translation>
    </message>
    <message>
        <source>Cycling Power</source>
        <translation>Potència del pedaleig</translation>
    </message>
    <message>
        <source>Location and Navigation</source>
        <translation>Ubicació i navegació</translation>
    </message>
    <message>
        <source>Environmental Sensing</source>
        <translation>Sensibilitat ambiental</translation>
    </message>
    <message>
        <source>Body Composition</source>
        <translation>Composició corporal</translation>
    </message>
    <message>
        <source>User Data</source>
        <translation>Dades d&apos;usuari</translation>
    </message>
    <message>
        <source>Weight Scale</source>
        <translation>Escala del pes</translation>
    </message>
    <message>
        <source>Bond Management</source>
        <extracomment>Connection management (Bluetooth)</extracomment>
        <translation>Gestió dels enllaços</translation>
    </message>
    <message>
        <source>Continuous Glucose Monitoring</source>
        <translation>Monitoratge continu de la glucosa</translation>
    </message>
    <message>
        <source>Service Discovery Protocol</source>
        <translation>Protocol de descobriment de serveis</translation>
    </message>
    <message>
        <source>User Datagram Protocol</source>
        <translation>Protocol de datagrames d&apos;usuari</translation>
    </message>
    <message>
        <source>Radio Frequency Communication</source>
        <translation>Comunicació de radiofreqüència</translation>
    </message>
    <message>
        <source>Transmission Control Protocol</source>
        <translation>Protocol de control de la transmissió</translation>
    </message>
    <message>
        <source>Telephony Control Specification - Binary</source>
        <translation>Especificació de control de la telefonia - binari</translation>
    </message>
    <message>
        <source>Telephony Control Specification - AT</source>
        <translation>Especificació de control de la telefonia - AT</translation>
    </message>
    <message>
        <source>Attribute Protocol</source>
        <translation>Protocol dels atributs</translation>
    </message>
    <message>
        <source>Object Exchange Protocol</source>
        <translation>Protocol d&apos;intercanvi d&apos;objectes</translation>
    </message>
    <message>
        <source>Internet Protocol</source>
        <translation>Protocol d&apos;Internet</translation>
    </message>
    <message>
        <source>File Transfer Protocol</source>
        <translation>Protocol de transferència de fitxers</translation>
    </message>
    <message>
        <source>Hypertext Transfer Protocol</source>
        <translation>Protocol de transferència d&apos;hipertext</translation>
    </message>
    <message>
        <source>Wireless Short Packet Protocol</source>
        <translation>Protocol sense fils de paquets de curt abast</translation>
    </message>
    <message>
        <source>Bluetooth Network Encapsulation Protocol</source>
        <translation>Protocol d&apos;encapsulament de la xarxa Bluetooth</translation>
    </message>
    <message>
        <source>Extended Service Discovery Protocol</source>
        <translation>Protocol ampliat de descobriment de serveis</translation>
    </message>
    <message>
        <source>Human Interface Device Protocol</source>
        <translation>Protocol de dispositius d&apos;interfície humana</translation>
    </message>
    <message>
        <source>Hardcopy Control Channel</source>
        <translation>Canal de control de la còpia</translation>
    </message>
    <message>
        <source>Hardcopy Data Channel</source>
        <translation>Canal de dades de la còpia</translation>
    </message>
    <message>
        <source>Hardcopy Notification</source>
        <translation>Notificació de la còpia</translation>
    </message>
    <message>
        <source>Audio/Video Control Transport Protocol</source>
        <translation>Protocol de transport del control de l&apos;àudio/vídeo</translation>
    </message>
    <message>
        <source>Audio/Video Distribution Transport Protocol</source>
        <translation>Protocol de transport de la distribució de l&apos;àudio/vídeo</translation>
    </message>
    <message>
        <source>Common ISDN Access Protocol</source>
        <translation>Protocol d&apos;accés XDSI comú</translation>
    </message>
    <message>
        <source>UdiCPlain</source>
        <translation>UdiCPlain</translation>
    </message>
    <message>
        <source>Multi-Channel Adaptation Protocol - Control</source>
        <translation>Protocol d&apos;adaptació multicanal - control</translation>
    </message>
    <message>
        <source>Multi-Channel Adaptation Protocol - Data</source>
        <translation>Protocol d&apos;adaptació multicanal - dades</translation>
    </message>
    <message>
        <source>Layer 2 Control Protocol</source>
        <translation>Protocol de control de capa 2</translation>
    </message>
    <message>
        <source>GAP Device Name</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>Nom del dispositiu GAP</translation>
    </message>
    <message>
        <source>GAP Appearance</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>Aparença GAP</translation>
    </message>
    <message>
        <source>GAP Peripheral Privacy Flag</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>Indicador de la privadesa del perifèric GAP</translation>
    </message>
    <message>
        <source>GAP Reconnection Address</source>
        <extracomment>GAP: Generic Access Profile (Bluetooth)</extracomment>
        <translation>Adreça de reconnexió GAP</translation>
    </message>
    <message>
        <source>GAP Peripheral Preferred Connection Parameters</source>
        <translation>Paràmetres de connexió preferits dels perifèrics GAP</translation>
    </message>
    <message>
        <source>GATT Service Changed</source>
        <extracomment>GATT: _G_eneric _Att_ribute Profile (Bluetooth)</extracomment>
        <translation>El servei GATT ha canviat</translation>
    </message>
    <message>
        <source>Alert Level</source>
        <translation>Nivell d&apos;alerta</translation>
    </message>
    <message>
        <source>TX Power</source>
        <translation>Potència de TX</translation>
    </message>
    <message>
        <source>Date Time</source>
        <translation>Hora i data</translation>
    </message>
    <message>
        <source>Day Of Week</source>
        <translation>Dia de la setmana</translation>
    </message>
    <message>
        <source>Day Date Time</source>
        <translation>Hora i data del dia</translation>
    </message>
    <message>
        <source>Exact Time 256</source>
        <translation>Hora exacta 256</translation>
    </message>
    <message>
        <source>DST Offset</source>
        <translation>Compensació de l&apos;horari d&apos;estiu</translation>
    </message>
    <message>
        <source>Time Zone</source>
        <translation>Zona horària</translation>
    </message>
    <message>
        <source>Local Time Information</source>
        <translation>Informació de l&apos;hora local</translation>
    </message>
    <message>
        <source>Time With DST</source>
        <translation>Hora amb l&apos;horari d&apos;estiu</translation>
    </message>
    <message>
        <source>Time Accuracy</source>
        <translation>Precisió de l&apos;hora</translation>
    </message>
    <message>
        <source>Time Source</source>
        <translation>Origen de l&apos;hora</translation>
    </message>
    <message>
        <source>Reference Time Information</source>
        <translation>Informació de l&apos;hora de referència</translation>
    </message>
    <message>
        <source>Time Update Control Point</source>
        <translation>Punt de control d&apos;actualització de l&apos;hora</translation>
    </message>
    <message>
        <source>Time Update State</source>
        <translation>Estat d&apos;actualització de l&apos;hora</translation>
    </message>
    <message>
        <source>Glucose Measurement</source>
        <translation>Mesura de la glucosa</translation>
    </message>
    <message>
        <source>Battery Level</source>
        <translation>Nivell de la bateria</translation>
    </message>
    <message>
        <source>Temperature Measurement</source>
        <translation>Mesura de la temperatura</translation>
    </message>
    <message>
        <source>Temperature Type</source>
        <translation>Tipus de temperatura</translation>
    </message>
    <message>
        <source>Intermediate Temperature</source>
        <translation>Temperatura intermèdia</translation>
    </message>
    <message>
        <source>Measurement Interval</source>
        <translation>Interval de mesura</translation>
    </message>
    <message>
        <source>Boot Keyboard Input Report</source>
        <translation>Informe de l&apos;arrencada de l&apos;entrada del teclat</translation>
    </message>
    <message>
        <source>System ID</source>
        <translation>ID del sistema</translation>
    </message>
    <message>
        <source>Model Number String</source>
        <translation>Cadena del número del model</translation>
    </message>
    <message>
        <source>Serial Number String</source>
        <translation>Cadena del número sèrie</translation>
    </message>
    <message>
        <source>Firmware Revision String</source>
        <translation>Cadena de la revisió del microprogramari</translation>
    </message>
    <message>
        <source>Hardware Revision String</source>
        <translation>Cadena de la revisió del maquinari</translation>
    </message>
    <message>
        <source>Software Revision String</source>
        <translation>Cadena de la revisió del programari</translation>
    </message>
    <message>
        <source>Manufacturer Name String</source>
        <translation>Cadena del nom del fabricant</translation>
    </message>
    <message>
        <source>IEEE 11073 20601 Regulatory Certification Data List</source>
        <translation>Llista de dades de la certificació reguladora IEEE 11073 20601</translation>
    </message>
    <message>
        <source>Current Time</source>
        <translation>Hora actual</translation>
    </message>
    <message>
        <source>Scan Refresh</source>
        <translation>Actualització de l&apos;escaneig</translation>
    </message>
    <message>
        <source>Boot Keyboard Output Report</source>
        <translation>Informe de l&apos;arrencada de la sortida del teclat</translation>
    </message>
    <message>
        <source>Boot Mouse Input Report</source>
        <translation>Informe de l&apos;arrencada de l&apos;entrada del ratolí</translation>
    </message>
    <message>
        <source>Glucose Measurement Context</source>
        <translation>Context en la mesura de la glucosa</translation>
    </message>
    <message>
        <source>Blood Pressure Measurement</source>
        <translation>Mesura de la pressió arterial</translation>
    </message>
    <message>
        <source>Intermediate Cuff Pressure</source>
        <translation>Pressió intermèdia del maneguet</translation>
    </message>
    <message>
        <source>Heart Rate Measurement</source>
        <translation>Mesura del ritme cardíac</translation>
    </message>
    <message>
        <source>Body Sensor Location</source>
        <translation>Ubicació del sensor corporal</translation>
    </message>
    <message>
        <source>Heart Rate Control Point</source>
        <translation>Punt de control del ritme cardíac</translation>
    </message>
    <message>
        <source>Alert Status</source>
        <translation>Estat d&apos;alerta</translation>
    </message>
    <message>
        <source>Ringer Control Point</source>
        <translation>Punt de control del timbre</translation>
    </message>
    <message>
        <source>Ringer Setting</source>
        <translation>Paràmetre del timbre</translation>
    </message>
    <message>
        <source>Alert Category ID Bit Mask</source>
        <translation>Màscara de bits de l&apos;ID de la categoria d&apos;alerta</translation>
    </message>
    <message>
        <source>Alert Category ID</source>
        <translation>ID de la categoria d&apos;alerta</translation>
    </message>
    <message>
        <source>Alert Notification Control Point</source>
        <translation>Punt de control de la notificació d&apos;alertes</translation>
    </message>
    <message>
        <source>Unread Alert Status</source>
        <translation>Estat d&apos;alerta sense llegir</translation>
    </message>
    <message>
        <source>New Alert</source>
        <translation>Alerta nova</translation>
    </message>
    <message>
        <source>Supported New Alert Category</source>
        <translation>Categoria admesa d&apos;alerta nova</translation>
    </message>
    <message>
        <source>Supported Unread Alert Category</source>
        <translation>Categoria admesa d&apos;alerta sense llegir</translation>
    </message>
    <message>
        <source>Blood Pressure Feature</source>
        <translation>Característica de la pressió arterial</translation>
    </message>
    <message>
        <source>HID Information</source>
        <extracomment>HID: Human Interface Device Profile (Bluetooth)</extracomment>
        <translation>Informació HID</translation>
    </message>
    <message>
        <source>Report Map</source>
        <translation>Mapa d&apos;informe</translation>
    </message>
    <message>
        <source>HID Control Point</source>
        <extracomment>HID: Human Interface Device Profile (Bluetooth)</extracomment>
        <translation>Punt de control HID</translation>
    </message>
    <message>
        <source>Report</source>
        <translation>Informe</translation>
    </message>
    <message>
        <source>Protocol Mode</source>
        <translation>Mode del protocol</translation>
    </message>
    <message>
        <source>Scan Interval Window</source>
        <translation>Finestra d&apos;interval de l&apos;escaneig</translation>
    </message>
    <message>
        <source>PnP ID</source>
        <translation>ID del PnP</translation>
    </message>
    <message>
        <source>Glucose Feature</source>
        <translation>Característica de la glucosa</translation>
    </message>
    <message>
        <source>Record Access Control Point</source>
        <extracomment>Glucose Sensor patient record database.</extracomment>
        <translation>Punt de control d&apos;accés al registre</translation>
    </message>
    <message>
        <source>RSC Measurement</source>
        <extracomment>RSC: Running Speed and Cadence</extracomment>
        <translation>Mesura de la velocitat i cadència de la carrera</translation>
    </message>
    <message>
        <source>RSC Feature</source>
        <extracomment>RSC: Running Speed and Cadence</extracomment>
        <translation>Característica de la velocitat i cadència de la carrera</translation>
    </message>
    <message>
        <source>SC Control Point</source>
        <translation>Punt de control de la velocitat i cadència</translation>
    </message>
    <message>
        <source>CSC Measurement</source>
        <extracomment>CSC: Cycling Speed and Cadence</extracomment>
        <translation>Mesura de la velocitat i cadència fent ciclisme</translation>
    </message>
    <message>
        <source>CSC Feature</source>
        <extracomment>CSC: Cycling Speed and Cadence</extracomment>
        <translation>Característica de la velocitat i cadència fent ciclisme</translation>
    </message>
    <message>
        <source>Sensor Location</source>
        <translation>Ubicació del sensor</translation>
    </message>
    <message>
        <source>Cycling Power Measurement</source>
        <translation>Mesura de la potència fent ciclisme</translation>
    </message>
    <message>
        <source>Cycling Power Vector</source>
        <translation>Vector de la potència fent ciclisme</translation>
    </message>
    <message>
        <source>Cycling Power Feature</source>
        <translation>Característica de la potència fent ciclisme</translation>
    </message>
    <message>
        <source>Cycling Power Control Point</source>
        <translation>Punt de control de la potència fent ciclisme</translation>
    </message>
    <message>
        <source>Location And Speed</source>
        <translation>Ubicació i velocitat</translation>
    </message>
    <message>
        <source>Navigation</source>
        <translation>Navegació</translation>
    </message>
    <message>
        <source>Position Quality</source>
        <translation>Qualitat de la posició</translation>
    </message>
    <message>
        <source>LN Feature</source>
        <translation>Característica de LN</translation>
    </message>
    <message>
        <source>LN Control Point</source>
        <translation>Punt de control del LN</translation>
    </message>
    <message>
        <source>Magnetic Declination</source>
        <extracomment>Angle between geographic and magnetic north</extracomment>
        <translation>Declinació magnètica</translation>
    </message>
    <message>
        <source>Elevation</source>
        <extracomment>Above/below sea level</extracomment>
        <translation>Elevació</translation>
    </message>
    <message>
        <source>Pressure</source>
        <translation>Pressió</translation>
    </message>
    <message>
        <source>Temperature</source>
        <translation>Temperatura</translation>
    </message>
    <message>
        <source>Humidity</source>
        <translation>Humitat</translation>
    </message>
    <message>
        <source>True Wind Speed</source>
        <extracomment>Wind speed while standing</extracomment>
        <translation>Velocitat real del vent</translation>
    </message>
    <message>
        <source>True Wind Direction</source>
        <translation>Direcció real del vent</translation>
    </message>
    <message>
        <source>Apparent Wind Speed</source>
        <extracomment>Wind speed while observer is moving</extracomment>
        <translation>Velocitat aparent del vent</translation>
    </message>
    <message>
        <source>Apparent Wind Direction</source>
        <translation>Direcció aparent del vent</translation>
    </message>
    <message>
        <source>Gust Factor</source>
        <extracomment>Factor by which wind gust is stronger than average wind</extracomment>
        <translation>Factor de ràfegues</translation>
    </message>
    <message>
        <source>Pollen Concentration</source>
        <translation>Concentració de pol·len</translation>
    </message>
    <message>
        <source>UV Index</source>
        <translation>Índex de llum ultraviolada</translation>
    </message>
    <message>
        <source>Irradiance</source>
        <translation>Irradiància</translation>
    </message>
    <message>
        <source>Rainfall</source>
        <translation>Precipitació</translation>
    </message>
    <message>
        <source>Wind Chill</source>
        <translation>Sensació tèrmica</translation>
    </message>
    <message>
        <source>Heat Index</source>
        <translation>Índex de calor</translation>
    </message>
    <message>
        <source>Dew Point</source>
        <translation>Punt de rosada</translation>
    </message>
    <message>
        <source>Descriptor Value Changed</source>
        <extracomment>Environmental sensing related</extracomment>
        <translation>El valor del descriptor ha canviat</translation>
    </message>
    <message>
        <source>Aerobic Heart Rate Lower Limit</source>
        <translation>Límit inferior aeròbic del ritme cardíac</translation>
    </message>
    <message>
        <source>Aerobic Heart Rate Upper Limit</source>
        <translation>Límit superior aeròbic del ritme cardíac</translation>
    </message>
    <message>
        <source>Aerobic Threshold</source>
        <translation>Llindar aeròbic</translation>
    </message>
    <message>
        <source>Age</source>
        <extracomment>Age of person</extracomment>
        <translation>Edat</translation>
    </message>
    <message>
        <source>Anaerobic Heart Rate Lower Limit</source>
        <translation>Límit inferior anaeròbic del ritme cardíac</translation>
    </message>
    <message>
        <source>Anaerobic Heart Rate Upper Limit</source>
        <translation>Límit superior anaeròbic del ritme cardíac</translation>
    </message>
    <message>
        <source>Anaerobic Threshold</source>
        <translation>Llindar anaeròbic</translation>
    </message>
    <message>
        <source>Date Of Birth</source>
        <translation>Data de naixement</translation>
    </message>
    <message>
        <source>Date Of Threshold Assessment</source>
        <translation>Data de l&apos;avaluació del llindar</translation>
    </message>
    <message>
        <source>Email Address</source>
        <translation>Adreça de correu electrònic</translation>
    </message>
    <message>
        <source>Fat Burn Heart Rate Lower Limit</source>
        <translation>Límit inferior del ritme cardíac cremant calories</translation>
    </message>
    <message>
        <source>Fat Burn Heart Rate Upper Limit</source>
        <translation>Límit superior del ritme cardíac cremant calories</translation>
    </message>
    <message>
        <source>First Name</source>
        <translation>Nom</translation>
    </message>
    <message>
        <source>5-Zone Heart Rate Limits</source>
        <translation>Límits de 5 zones del ritme cardíac</translation>
    </message>
    <message>
        <source>Gender</source>
        <translation>Sexe</translation>
    </message>
    <message>
        <source>Heart Rate Maximum</source>
        <translation>Pulsacions màximes</translation>
    </message>
    <message>
        <source>Height</source>
        <extracomment>Height of a person</extracomment>
        <translation>Altura</translation>
    </message>
    <message>
        <source>Hip Circumference</source>
        <translation>Circumferència del maluc</translation>
    </message>
    <message>
        <source>Last Name</source>
        <translation>Cognoms</translation>
    </message>
    <message>
        <source>Maximum Recommended Heart Rate</source>
        <translation>Pulsacions màximes recomanades</translation>
    </message>
    <message>
        <source>Resting Heart Rate</source>
        <translation>Pulsacions en repòs</translation>
    </message>
    <message>
        <source>Sport Type For Aerobic/Anaerobic Thresholds</source>
        <translation>Tipus d&apos;esport per als llindars aeròbics/anaeròbics</translation>
    </message>
    <message>
        <source>3-Zone Heart Rate Limits</source>
        <translation>Límits de 3 zones del ritme cardíac</translation>
    </message>
    <message>
        <source>2-Zone Heart Rate Limits</source>
        <translation>Límits de 2 zones del ritme cardíac</translation>
    </message>
    <message>
        <source>Oxygen Uptake</source>
        <translation>Absorció d&apos;oxigen</translation>
    </message>
    <message>
        <source>Waist Circumference</source>
        <translation>Circumferència de la cintura</translation>
    </message>
    <message>
        <source>Weight</source>
        <translation>Pes</translation>
    </message>
    <message>
        <source>Database Change Increment</source>
        <extracomment>Environmental sensing related</extracomment>
        <translation>Increment de canvi de la base de dades</translation>
    </message>
    <message>
        <source>User Index</source>
        <translation>Índex d&apos;usuari</translation>
    </message>
    <message>
        <source>Body Composition Feature</source>
        <translation>Característica de la composició corporal</translation>
    </message>
    <message>
        <source>Body Composition Measurement</source>
        <translation>Mesura de la composició corporal</translation>
    </message>
    <message>
        <source>Weight Measurement</source>
        <translation>Mesura del pes</translation>
    </message>
    <message>
        <source>Weight Scale Feature</source>
        <translation>Característica de l&apos;escala de pes</translation>
    </message>
    <message>
        <source>User Control Point</source>
        <translation>Punt de control de l&apos;usuari</translation>
    </message>
    <message>
        <source>Magnetic Flux Density 2D</source>
        <translation>Densitat en 2D del flux magnètic</translation>
    </message>
    <message>
        <source>Magnetic Flux Density 3D</source>
        <translation>Densitat en 3D del flux magnètic</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Idioma</translation>
    </message>
    <message>
        <source>Barometric Pressure Trend</source>
        <translation>Tendència de la pressió baromètrica</translation>
    </message>
    <message>
        <source>Characteristic Extended Properties</source>
        <translation>Propietats esteses de les característiques</translation>
    </message>
    <message>
        <source>Characteristic User Description</source>
        <translation>Característica de descripció de l&apos;usuari</translation>
    </message>
    <message>
        <source>Client Characteristic Configuration</source>
        <translation>Configuració de la característica del client</translation>
    </message>
    <message>
        <source>Server Characteristic Configuration</source>
        <translation>Configuració de la característica del servidor</translation>
    </message>
    <message>
        <source>Characteristic Presentation Format</source>
        <translation>Format de la presentació de la característica</translation>
    </message>
    <message>
        <source>Characteristic Aggregate Format</source>
        <translation>Format de l&apos;agregat de la característica</translation>
    </message>
    <message>
        <source>Valid Range</source>
        <translation>Interval vàlid</translation>
    </message>
    <message>
        <source>External Report Reference</source>
        <translation>Referència de l&apos;informe extern</translation>
    </message>
    <message>
        <source>Report Reference</source>
        <translation>Referència de l&apos;informe</translation>
    </message>
    <message>
        <source>Environmental Sensing Configuration</source>
        <translation>Configuració de la detecció ambiental</translation>
    </message>
    <message>
        <source>Environmental Sensing Measurement</source>
        <translation>Mesura de la detecció ambiental</translation>
    </message>
    <message>
        <source>Environmental Sensing Trigger Setting</source>
        <translation>Configuració de l&apos;activador de detecció ambiental</translation>
    </message>
    <message>
        <source>Unknown Service</source>
        <translation>Servei desconegut</translation>
    </message>
</context>
<context>
    <name>QBluetoothSocket</name>
    <message>
        <source>Network Error</source>
        <translation>Error de xarxa</translation>
    </message>
    <message>
        <source>Cannot write while not connected</source>
        <translation>No es pot escriure mentre no està connectat</translation>
    </message>
    <message>
        <source>Trying to connect while connection is in progress</source>
        <translation>S&apos;intenta connectar mentre la connexió és en curs</translation>
    </message>
    <message>
        <source>Service cannot be found</source>
        <translation>No s&apos;ha pogut trobar el servei</translation>
    </message>
    <message>
        <source>Invalid data/data size</source>
        <translation>Dades no vàlides/mida de les dades</translation>
    </message>
    <message>
        <source>Cannot read while not connected</source>
        <translation>No es pot llegir quan no està connectat</translation>
    </message>
    <message>
        <source>Socket type not supported</source>
        <translation>El tipus de sòcol no està admès</translation>
    </message>
    <message>
        <source>Unknown socket error</source>
        <translation>Error desconegut de sòcol</translation>
    </message>
    <message>
        <source>Network Error: %1</source>
        <translation>Error de xarxa: %1</translation>
    </message>
    <message>
        <source>Connecting to port is not supported</source>
        <translation type="vanished">No s&apos;admet connectar amb el port</translation>
    </message>
    <message>
        <source>Cannot connect to %1</source>
        <comment>%1 = uuid</comment>
        <translation>No s&apos;ha pogut connectar a %1</translation>
    </message>
    <message>
        <source>Bluetooth socket connect failed due to missing permissions.</source>
        <translation>Ha fallat la connexió al sòcol de Bluetooth a causa de la manca de permisos.</translation>
    </message>
    <message>
        <source>Device does not support Bluetooth</source>
        <translation>El dispositiu no admet Bluetooth</translation>
    </message>
    <message>
        <source>Device is powered off</source>
        <translation>El dispositiu està apagat</translation>
    </message>
    <message>
        <source>Cannot access address %1</source>
        <comment>%1 = Bt address e.g. 11:22:33:44:55:66</comment>
        <translation>No s&apos;ha pogut accedir a l&apos;adreça %1</translation>
    </message>
    <message>
        <source>Cannot connect to %1 on %2</source>
        <comment>%1 = uuid, %2 = Bt address</comment>
        <translation>No s&apos;ha pogut connectar amb %1 a %2</translation>
    </message>
    <message>
        <source>Obtaining streams for service failed</source>
        <translation>Ha fallat l&apos;obtenció dels fluxos per al servei</translation>
    </message>
    <message>
        <source>Input stream thread cannot be started</source>
        <translation>No s&apos;ha pogut iniciar el fil del flux d&apos;entrada</translation>
    </message>
    <message>
        <source>Connection to service failed</source>
        <translation>Ha fallat la connexió amb el servei</translation>
    </message>
    <message>
        <source>Error during write on socket.</source>
        <translation>Error mentre s&apos;escrivia al sòcol.</translation>
    </message>
    <message>
        <source>Network error during read</source>
        <translation>Error de xarxa mentre es llegia</translation>
    </message>
    <message>
        <source>Cannot set connection security level</source>
        <translation>No s&apos;ha pogut establir el nivell de seguretat</translation>
    </message>
    <message>
        <source>Cannot export profile on DBus</source>
        <translation>No s&apos;ha pogut exportar el perfil al DBus</translation>
    </message>
    <message>
        <source>Cannot register profile on DBus</source>
        <translation>No s&apos;ha pogut registrar el perfil al DBus</translation>
    </message>
    <message>
        <source>Cannot find remote device</source>
        <translation>No s&apos;ha pogut trobar el dispositiu remot</translation>
    </message>
    <message>
        <source>Cannot connect to remote profile</source>
        <translation>No s&apos;ha pogut connectar al perfil remot</translation>
    </message>
    <message>
        <source>Missing serviceUuid or Serial Port service class uuid</source>
        <translation>Manca el «serviceUuid» o l&apos;UUID de la classe de servei «Serial Port»</translation>
    </message>
    <message>
        <source>Invalid Bluetooth address passed to connectToService()</source>
        <translation>Adreça Bluetooth no vàlida passada a «connectToService()»</translation>
    </message>
    <message>
        <source>Unsupported protocol. Win32 only supports RFCOMM sockets</source>
        <translation type="vanished">Protocol no admès. El Win32 només admet sòcols RFCOMM</translation>
    </message>
    <message>
        <source>Failed to create socket</source>
        <translation type="vanished">Ha fallat en crear el sòcol</translation>
    </message>
    <message>
        <source>Socket type not handled: %1</source>
        <translation type="vanished">Tipus de sòcol no gestionat: %1</translation>
    </message>
    <message>
        <source>Logic error: more bytes sent than passed to ::send</source>
        <translation type="vanished">Error lògic: s&apos;han enviat més bytes que els passats a «::send»</translation>
    </message>
    <message>
        <source>Network error</source>
        <translation>Error de xarxa</translation>
    </message>
    <message>
        <source>Remote host closed connection</source>
        <translation>L&apos;ordinador remot ha tancat la connexió</translation>
    </message>
    <message>
        <source>Connection timed out</source>
        <translation>La connexió ha caducat</translation>
    </message>
    <message>
        <source>Host not reachable</source>
        <translation>L&apos;ordinador és inaccessible</translation>
    </message>
    <message>
        <source>Host refused connection</source>
        <translation>L&apos;ordinador ha refusat la connexió</translation>
    </message>
</context>
<context>
    <name>QBluetoothSocketPrivateAndroid</name>
    <message>
        <source>Connecting to port is not supported</source>
        <translation>No s&apos;admet connectar al port</translation>
    </message>
</context>
<context>
    <name>QBluetoothSocketPrivateBluezDBus</name>
    <message>
        <source>Connecting to port is not supported via Bluez DBus</source>
        <translation>No s&apos;admet connectar al port via el DBus del Bluez</translation>
    </message>
</context>
<context>
    <name>QBluetoothTransferReply</name>
    <message>
        <source>Invalid target address</source>
        <translation>Adreça de destinació no vàlida</translation>
    </message>
    <message>
        <source>Push session cannot be started</source>
        <translation>No s&apos;ha pogut iniciar la sessió de pujada</translation>
    </message>
    <message>
        <source>Push session cannot connect</source>
        <translation>No s&apos;ha pogut connectar la sessió de pujada</translation>
    </message>
    <message>
        <source>Source file does not exist</source>
        <translation>El fitxer d&apos;origen no existeix</translation>
    </message>
    <message>
        <source>QIODevice cannot be read. Make sure it is open for reading.</source>
        <translation>El «QIODevice» no es pot llegir. Assegureu-vos que està obert per a lectura.</translation>
    </message>
    <message>
        <source>Push session failed</source>
        <translation>La sessió de pujada ha fallat</translation>
    </message>
    <message>
        <source>Invalid input device (null)</source>
        <translation>Dispositiu d&apos;entrada no vàlid (nul)</translation>
    </message>
    <message>
        <source>Operation canceled</source>
        <translation>Operació cancel·lada</translation>
    </message>
    <message>
        <source>Transfer already started</source>
        <translation>La transferència ja s&apos;ha iniciat</translation>
    </message>
    <message>
        <source>Push service not found</source>
        <translation>No s&apos;ha pogut trobar el servei de pujada</translation>
    </message>
</context>
<context>
    <name>QBluetoothTransferReplyBluez</name>
    <message>
        <source>Unknown Error</source>
        <translation type="vanished">Error desconegut</translation>
    </message>
    <message>
        <source>Could not open file for sending</source>
        <translation type="vanished">No s&apos;ha pogut obrir el fitxer per a enviar-lo</translation>
    </message>
    <message>
        <source>The transfer was canceled</source>
        <translation type="vanished">La transferència s&apos;ha cancel·lat</translation>
    </message>
    <message>
        <source>Operation canceled</source>
        <translation type="vanished">Operació cancel·lada</translation>
    </message>
</context>
<context>
    <name>QLowEnergyController</name>
    <message>
        <source>Remote device cannot be found</source>
        <translation>No s&apos;ha pogut trobar el dispositiu remot</translation>
    </message>
    <message>
        <source>Cannot find local adapter</source>
        <translation>No s&apos;ha pogut trobar l&apos;adaptador local</translation>
    </message>
    <message>
        <source>Error occurred during connection I/O</source>
        <translation>Ha succeït un error durant les E/S de la connexió</translation>
    </message>
    <message>
        <source>Unknown Error</source>
        <translation>Error desconegut</translation>
    </message>
    <message>
        <source>Missing permission</source>
        <translation>Manca un permís</translation>
    </message>
    <message>
        <source>Error occurred trying to connect to remote device.</source>
        <translation>Ha succeït un error en intentar connectar amb el dispositiu remot.</translation>
    </message>
    <message>
        <source>Remote device closed the connection</source>
        <translation>El dispositiu remot ha tancat la connexió</translation>
    </message>
    <message>
        <source>Failed to authorize on the remote device</source>
        <translation>Ha fallat l&apos;autorització al dispositiu remot</translation>
    </message>
    <message>
        <source>Missing permissions error</source>
        <translation>Error de manca de permisos</translation>
    </message>
    <message>
        <source>Error reading RSSI value</source>
        <translation>Error en llegir el valor del RSSI</translation>
    </message>
    <message>
        <source>Advertisement data is larger than 31 bytes</source>
        <translation>Les dades d&apos;anunci són més grans que 31 bytes</translation>
    </message>
    <message>
        <source>Advertisement feature not supported on the platform</source>
        <translation>La funcionalitat d&apos;anunci no està admesa a la plataforma</translation>
    </message>
    <message>
        <source>Error occurred trying to start advertising</source>
        <translation>Ha succeït un error en intentar iniciar l&apos;anunci</translation>
    </message>
    <message>
        <source>Failed due to too many advertisers</source>
        <translation>Ha fallat per massa anunciants</translation>
    </message>
    <message>
        <source>Unknown advertisement error</source>
        <translation>Error desconegut d&apos;anunci</translation>
    </message>
</context>
</TS>
